@@ -12,17 +12,19 @@
 #define WIN_WIDTH  432
 #define WIN_HEIGHT 320
 
-typedef struct MailBox {
-    char           *entry;
-    char           *type;
-    char           *username;
-    char           *password;
-    char           *folder;
-    struct MailBox *next;
-} MailBox;
+typedef struct MailBox
+{
+        char *entry;
+        char *type;
+        char *username;
+        char *password;
+        char *folder;
+        struct MailBox *next;
+}
+MailBox;
 
 #ifndef TRUE
-# define TRUE  1
+# define TRUE 1
 # define FALSE 0
 #endif
 
